@@ -1,7 +1,7 @@
 """
 Type annotations for kms service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/type_defs/)
 
 Usage::
 
@@ -99,12 +99,16 @@ __all__ = (
     "ImportKeyMaterialRequestRequestTypeDef",
     "KeyListEntryTypeDef",
     "KeyMetadataTypeDef",
+    "ListAliasesRequestListAliasesPaginateTypeDef",
     "ListAliasesRequestRequestTypeDef",
     "ListAliasesResponseTypeDef",
+    "ListGrantsRequestListGrantsPaginateTypeDef",
     "ListGrantsRequestRequestTypeDef",
     "ListGrantsResponseTypeDef",
+    "ListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef",
     "ListKeyPoliciesRequestRequestTypeDef",
     "ListKeyPoliciesResponseTypeDef",
+    "ListKeysRequestListKeysPaginateTypeDef",
     "ListKeysRequestRequestTypeDef",
     "ListKeysResponseTypeDef",
     "ListResourceTagsRequestRequestTypeDef",
@@ -273,7 +277,7 @@ CustomKeyStoresListEntryTypeDef = TypedDict(
 _RequiredDecryptRequestRequestTypeDef = TypedDict(
     "_RequiredDecryptRequestRequestTypeDef",
     {
-        "CiphertextBlob": Union[bytes, IO[bytes], StreamingBody],
+        "CiphertextBlob": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalDecryptRequestRequestTypeDef = TypedDict(
@@ -414,7 +418,7 @@ _RequiredEncryptRequestRequestTypeDef = TypedDict(
     "_RequiredEncryptRequestRequestTypeDef",
     {
         "KeyId": str,
-        "Plaintext": Union[bytes, IO[bytes], StreamingBody],
+        "Plaintext": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalEncryptRequestRequestTypeDef = TypedDict(
@@ -715,8 +719,8 @@ _RequiredImportKeyMaterialRequestRequestTypeDef = TypedDict(
     "_RequiredImportKeyMaterialRequestRequestTypeDef",
     {
         "KeyId": str,
-        "ImportToken": Union[bytes, IO[bytes], StreamingBody],
-        "EncryptedKeyMaterial": Union[bytes, IO[bytes], StreamingBody],
+        "ImportToken": Union[str, bytes, IO[Any], StreamingBody],
+        "EncryptedKeyMaterial": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalImportKeyMaterialRequestRequestTypeDef = TypedDict(
@@ -783,6 +787,15 @@ class KeyMetadataTypeDef(_RequiredKeyMetadataTypeDef, _OptionalKeyMetadataTypeDe
     pass
 
 
+ListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
+    "ListAliasesRequestListAliasesPaginateTypeDef",
+    {
+        "KeyId": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListAliasesRequestRequestTypeDef = TypedDict(
     "ListAliasesRequestRequestTypeDef",
     {
@@ -803,6 +816,30 @@ ListAliasesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListGrantsRequestListGrantsPaginateTypeDef = TypedDict(
+    "_RequiredListGrantsRequestListGrantsPaginateTypeDef",
+    {
+        "KeyId": str,
+    },
+)
+_OptionalListGrantsRequestListGrantsPaginateTypeDef = TypedDict(
+    "_OptionalListGrantsRequestListGrantsPaginateTypeDef",
+    {
+        "GrantId": str,
+        "GranteePrincipal": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListGrantsRequestListGrantsPaginateTypeDef(
+    _RequiredListGrantsRequestListGrantsPaginateTypeDef,
+    _OptionalListGrantsRequestListGrantsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListGrantsRequestRequestTypeDef = TypedDict(
     "_RequiredListGrantsRequestRequestTypeDef",
     {
@@ -837,6 +874,28 @@ ListGrantsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef = TypedDict(
+    "_RequiredListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef",
+    {
+        "KeyId": str,
+    },
+)
+_OptionalListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef = TypedDict(
+    "_OptionalListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef(
+    _RequiredListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef,
+    _OptionalListKeyPoliciesRequestListKeyPoliciesPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListKeyPoliciesRequestRequestTypeDef = TypedDict(
     "_RequiredListKeyPoliciesRequestRequestTypeDef",
     {
@@ -869,6 +928,14 @@ ListKeyPoliciesResponseTypeDef = TypedDict(
     },
 )
 
+ListKeysRequestListKeysPaginateTypeDef = TypedDict(
+    "ListKeysRequestListKeysPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListKeysRequestRequestTypeDef = TypedDict(
     "ListKeysRequestRequestTypeDef",
     {
@@ -998,7 +1065,7 @@ class PutKeyPolicyRequestRequestTypeDef(
 _RequiredReEncryptRequestRequestTypeDef = TypedDict(
     "_RequiredReEncryptRequestRequestTypeDef",
     {
-        "CiphertextBlob": Union[bytes, IO[bytes], StreamingBody],
+        "CiphertextBlob": Union[str, bytes, IO[Any], StreamingBody],
         "DestinationKeyId": str,
     },
 )
@@ -1075,7 +1142,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1135,7 +1202,7 @@ _RequiredSignRequestRequestTypeDef = TypedDict(
     "_RequiredSignRequestRequestTypeDef",
     {
         "KeyId": str,
-        "Message": Union[bytes, IO[bytes], StreamingBody],
+        "Message": Union[str, bytes, IO[Any], StreamingBody],
         "SigningAlgorithm": SigningAlgorithmSpecType,
     },
 )
@@ -1241,8 +1308,8 @@ _RequiredVerifyRequestRequestTypeDef = TypedDict(
     "_RequiredVerifyRequestRequestTypeDef",
     {
         "KeyId": str,
-        "Message": Union[bytes, IO[bytes], StreamingBody],
-        "Signature": Union[bytes, IO[bytes], StreamingBody],
+        "Message": Union[str, bytes, IO[Any], StreamingBody],
+        "Signature": Union[str, bytes, IO[Any], StreamingBody],
         "SigningAlgorithm": SigningAlgorithmSpecType,
     },
 )
